window.Gleam.initSearch([{"doc":"varasto","title":"varasto","content":"# varasto\n\n[![Package Version](https://img.shields.io/hexpm/v/varasto)](https://hex.pm/packages/varasto)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/varasto/)\n\nTyped access to the [Web Storage API](https://developer.mozilla.org/en-US/docs/Web/API/Web_Storage_API), i.e. LocalStorage and SessionStorage.\n\nThis package is only for the JavaScript target. It depends on [plinth](https://hexdocs.pm/plinth/index.html), which implements the lower level (string only) Web Storage API access. Thus, if you only intend to read and write string values, you may use plinth directly.\n\n## Usage\n\nVarasto uses JSON as the storage format. To use it, you will need to construct a `TypedStorage` value that encapsulates a reader and a writer to convert the value to and from `gleam/json.Json`.\n\nAn example where the data type is a list of integers:\n\n```gleam\nimport gleam/dynamic\nimport gleam/json\nimport plinth/javascript/storage\nimport varasto\n\n// Reader that decodes a Dynamic to a list of integers\nfn int_list_reader() {\n  dynamic.list(dynamic.int)\n}\n\n// A writer that converts a list of integers to a Json value\nfn int_list_writer() {\n  fn(val: List(Int)) { json.array(val, json.int) }\n}\n\n// First use plinth to get the low level storage\nlet assert Ok(local) = storage.local()\n\n// Construct TypedStorage with the reader and writer\nlet s = varasto.new(local, int_list_reader(), int_list_writer())\n\n// Set a value\nvarasto.set(s, &quot;Foo&quot;, [1, 2, 3])\n\n// Returns Ok([1, 2, 3])\nvarasto.get(s, &quot;Foo&quot;)\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add varasto\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/varasto&gt;.\n","url":"index.html"},{"doc":"varasto","title":"ReadError","content":"pub type ReadError {\n  NotFound\n  DecodeError(err: json.DecodeError)\n}\n An error that occurs when reading.\nNotFound\n A value was not found with the given key.\n\nDecodeError(err: json.DecodeError)\n The found value could not be decoded.\n\nSynonyms:\nvarasto.ReadError\nvarasto ReadError","url":"varasto.html#ReadError"},{"doc":"varasto","title":"TypedStorage","content":"pub opaque type TypedStorage(a)\n\n\nSynonyms:\nvarasto.TypedStorage\nvarasto TypedStorage","url":"varasto.html#TypedStorage"},{"doc":"varasto","title":"clear","content":"pub fn clear(storage: TypedStorage(a)) -&gt; Nil\n Clear the whole storage.\n\n NOTE! This will clear the whole storage, not just values you have set.\nSynonyms:\nvarasto.clear\nvarasto clear","url":"varasto.html#clear"},{"doc":"varasto","title":"get","content":"pub fn get(\n  storage: TypedStorage(a),\n  key: String,\n) -&gt; Result(a, ReadError)\n Get a value from the storage.\nSynonyms:\nvarasto.get\nvarasto get","url":"varasto.html#get"},{"doc":"varasto","title":"new","content":"pub fn new(\n  raw_storage: Storage,\n  reader: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  writer: fn(a) -&gt; Json,\n) -&gt; TypedStorage(a)\n Create a new `TypedStorage`.\nSynonyms:\nvarasto.new\nvarasto new","url":"varasto.html#new"},{"doc":"varasto","title":"remove","content":"pub fn remove(storage: TypedStorage(a), key: String) -&gt; Nil\n Remove a value from the storage.\nSynonyms:\nvarasto.remove\nvarasto remove","url":"varasto.html#remove"},{"doc":"varasto","title":"set","content":"pub fn set(\n  storage: TypedStorage(a),\n  key: String,\n  value: a,\n) -&gt; Result(Nil, Nil)\n Set a value in the storage.\nSynonyms:\nvarasto.set\nvarasto set","url":"varasto.html#set"},{"doc":"varasto","title":"varasto","content":" Typed access to the Web Storage API.","url":"varasto.html"}]);